"""KiCad python module for interpreting generic netlists which can be used to generate bills of materials."""
# This file is generated automatically from metadata
# File edits may be overwritten!
from kicad_netlist_reader.__about__ import (
    __author__,
    __copyright__,
    __email__,
    __license__,
    __description__,
    __url__,
    __version__)

from .kicad_netlist_reader import netlist, comp, xmlElement, libpart



"""KiCad python module for interpreting generic netlists which can be used to generate bills of materials."""
# This file is generated automatically from metadata
# File edits may be overwritten!

__version__ = '7.0.1'
__description__ = 'KiCad python module for interpreting generic netlists which can be used to generate bills of materials.'
__license__ = 'GPL-3.0'
__url__ = 'https://github.com/janelia-pypi/kicad_netlist_reader'
__author__ = 'Jean-Pierre Charras'
__email__ = 'jean-pierre.charras@wanadoo.fr'
__copyright__ = '2023 KiCad'



"""KiCad python module for interpreting generic netlists which can be used to generate bills of materials."""
# This file is generated automatically from metadata
# File edits may be overwritten!
from setuptools import setup


if __name__ == '__main__':
    setup()
